pub fn entry_len(name_len: usize, schema_len: usize) -> Result<usize>Expand description
The bytes an entry with this name and schema needs.
Errors
Code::Invalid if the name is longer than MAX_NAME_LEN.
pub fn entry_len(name_len: usize, schema_len: usize) -> Result<usize>The bytes an entry with this name and schema needs.
Code::Invalid if the name is longer than MAX_NAME_LEN.