get_floats

Function get_floats 

pub fn get_floats(bytes: &[u8], out: &mut [f32]) -> Result<()>
Reads floats back out of bytes into out, which says how many.

Errors

Code::Corrupt if there are not that many floats there, which is what a section that disagrees with the header it was described by looks like.