pub fn seal(slot: &mut [u8]) -> u32Expand description
Computes the slot checksum, stores it, and returns it.
Panics
If slot is not exactly SUPERBLOCK_LEN bytes.
pub fn seal(slot: &mut [u8]) -> u32Computes the slot checksum, stores it, and returns it.
If slot is not exactly SUPERBLOCK_LEN bytes.