#[repr(u8)]pub enum Element {
F32 = 0,
}Expand description
How one coordinate is stored.
The values are part of the format. See the module note on why there is a byte for this when there is only one of them.
Variants
F32 = 0
Little endian f32, four bytes.
Implementations