pub fn image_len(partitions: u32) -> Result<usize>Expand description
How long an image root with this many partitions is.
Errors
Code::Invalid if the partition count is large enough that the root would
not fit in a usize, which on a 64 bit machine it never is and on a 32 bit
one is a corrupt count rather than a real index.